@@ -31,7 +31,7 @@
             data = kismet.sanitizeObject(data);
 
             var devtitles = new Array();
-            var devnums = new Array();
+            var datasets = new Array();
 
             // Chart type from radio buttons
             var charttype = $("input[name='graphtype']:checked", state.graphtype).val();
@@ -45,7 +45,6 @@
             // historical line chart
             if (charttype === 'history') {
                 var pointtitles = new Array();
-                var datasets = new Array();
                 var title = "";
 
                 var rrd_data = null;
@@ -116,13 +115,9 @@
 
                 for (var fk in data['kismet.channeltracker.frequency_map']) {
                     var linedata =
-                        kismet.RecalcRrdData(
-                            data['kismet.channeltracker.frequency_map'][fk]['kismet.channelrec.device_rrd']['kismet.common.rrd.last_time'],
-                            data['kismet.channeltracker.frequency_map'][fk]['kismet.channelrec.device_rrd']['kismet.common.rrd.last_time'],
+                        kismet.RecalcRrdData2(
+                            data['kismet.channeltracker.frequency_map'][fk]['kismet.channelrec.device_rrd'],
                             rrd_type,
-                            kismet.ObjectByString(
-                                data['kismet.channeltracker.frequency_map'][fk],
-                                rrd_data),
                             {});
 
                     // Convert the freq name
@@ -187,15 +182,15 @@
                         options: {
                             maintainAspectRatio: false,
                             scales: {
-                                yAxes: [{
+                                y: {
                                     ticks: {
                                         beginAtZero: true,
                                     },
                                     stacked: true,
-                                }],
-                                xAxes: [{
+                                },
+                                x: {
                                     stacked: true,
-                                }],
+                                },
                             },
                             legend: {
                                 labels: {
@@ -225,6 +220,7 @@
                 // which is what we probably really want
 
                 var freqsort = Object.keys(data['kismet.channeltracker.frequency_map']).sort();
+                var devnums = new Array();
 
                 for (var fk of freqsort) {
                     var slot_now =
@@ -241,6 +237,13 @@
                     devnums.push(dev_now);
                 }
 
+                datasets.push({
+                    label: "Active devices per channel",
+                    backgroundColor: kismet_theme.graphBasicColor,
+                    data: devnums,
+                    borderWidth: 1,
+                });
+
                 state.devgraph_canvas.show();
                 state.timegraph_canvas.hide();
 
@@ -262,14 +265,7 @@
                         },
                         data: {
                             labels: devtitles,
-                            datasets: [
-                                {
-                                    label: "Active devices per channel",
-                                    backgroundColor: kismet_theme.graphBasicColor,
-                                    data: devnums,
-                                    borderWidth: 1,
-                                }
-                            ],
+                            datasets: datasets
                         }
                     };
 
@@ -277,9 +273,8 @@
                         device_options);
 
                 } else {
-                    state.devgraph_chart.data.datasets[0].data = devnums;
+                    state.devgraph_chart.data.datasets = datasets;
                     state.devgraph_chart.data.labels = devtitles;
-
                     state.devgraph_chart.update();
                 }
             }
