@@ -9,7 +9,7 @@
 
 var exports = {};
 
-var local_uri_prefix = ""; 
+var local_uri_prefix = "";
 if (typeof(KISMET_URI_PREFIX) !== 'undefined')
     local_uri_prefix = KISMET_URI_PREFIX;
 
@@ -61,7 +61,7 @@ exports.HumanReadableSize = function(sz) {
     if (typeof(sz) === 'undefined')
         return '0 B';
 
-    if (typeof(sz) !== 'number') 
+    if (typeof(sz) !== 'number')
         sz = parseInt(sz);
 
     if (sz < 1024) {
@@ -84,7 +84,7 @@ exports.HumanReadableFrequency = function(f) {
         return f + " KHz";
     else if (f < 1000 * 1000)
         return (f / 1000).toFixed(3) + " MHz";
-    else 
+    else
         return (f / 1000 / 1000).toFixed(3) + " GHz";
 }
 
@@ -92,7 +92,7 @@ exports.HumanReadableFrequency = function(f) {
 // applying a transform function which could do something like average it
 
 // Conversion factors / type definitions for RRD data arrays
-exports.RRD_SECOND = 1; 
+exports.RRD_SECOND = 1;
 exports.RRD_MINUTE = 60;
 exports.RRD_HOUR = 3600;
 
@@ -102,24 +102,24 @@ exports.RecalcRrdData = function(start, now, type, data, opt = {}) {
     if (data == undefined) {
         if (type == exports.RRD_SECOND || type == exports.RRD_MINUTE) {
             data = [
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0 
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0
             ];
         } else if (type == exports.RRD_HOUR) {
             data = [
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                 0, 0, 0, 0
             ];
         }
     }
 
-    var rrd_len = data.length;
+    let rrd_len = data.length;
 
     // Each type value is the number of seconds in each bin of the array
     //
@@ -129,29 +129,29 @@ exports.RecalcRrdData = function(start, now, type, data, opt = {}) {
     // be filled with only zeroes
     //
     // To zero the array between "then" and "now", we simply calculate
-    // the bin for "then", the bin for "now", and increment-with-modulo 
+    // the bin for "then", the bin for "now", and increment-with-modulo
     // until we reach "now".
 
     // Adjusted data we return
-    var adj_data = new Array();
+    let adj_data = new Array();
 
     // Check if we're past the recording bounds of the rrd for this type, if we
     // are, we don't have to do any shifting or any manipulation, we just fill
     // the array with zeroes.
     if ((now - start) > (type * rrd_len)) {
-        for (var ri = 0; ri < rrd_len; ri++) {
+        for (let ri = 0; ri < rrd_len; ri++) {
             adj_data.push(0);
         }
     } else {
         // Otherwise, we're valid inside the range of the array.  We know we got
-        // no data between the time of the RRD and now, because if we had, the 
+        // no data between the time of the RRD and now, because if we had, the
         // time would be more current.  Figure out how many bins lie between
         // 'then' and 'now', rescale the array to start at 'now', and fill
         // in the time we got no data with zeroes
-        
-        var start_bin = (Math.floor(start / type) % rrd_len) + 1;
-        var now_bin = (Math.floor(now / type) % rrd_len) + 1;
-        var sec_offt = Math.max(0, now - start);
+
+        let start_bin = (Math.floor(start / type) % rrd_len) + 1;
+        let now_bin = (Math.floor(now / type) % rrd_len) + 1;
+        let sec_offt = Math.max(0, now - start);
 
         /*
         console.log("we think we start in bin" + start_bin);
@@ -161,8 +161,8 @@ exports.RecalcRrdData = function(start, now, type, data, opt = {}) {
         // Walk the entire array, starting with 'now', and copy zeroes
         // when we fall into the blank spot between 'start' and 'now' when we
         // know we received no data
-        for (var ri = 0; ri < rrd_len; ri++) {
-            var slot = (now_bin + ri) % rrd_len;
+        for (let ri = 0; ri < rrd_len; ri++) {
+            let slot = (now_bin + ri) % rrd_len;
 
             if (slot >= start_bin && slot < now_bin)
                 adj_data.push(0);
@@ -174,7 +174,7 @@ exports.RecalcRrdData = function(start, now, type, data, opt = {}) {
     // If we have a transform function in the options, call it, otherwise
     // return the shifted RRD entry
     if ('transform' in opt && typeof(opt.transform) === 'function') {
-        var cbopt = {};
+        let cbopt = {};
 
         if ('transformopt' in opt)
             cbopt = opt.transformopt;
@@ -186,7 +186,7 @@ exports.RecalcRrdData = function(start, now, type, data, opt = {}) {
 }
 
 exports.RecalcRrdData2 = function(rrddata, type, opt = {}) {
-    var record;
+    let record = "";
 
     if (type == exports.RRD_SECOND)
         record = "kismet.common.rrd.minute_vec";
@@ -197,39 +197,42 @@ exports.RecalcRrdData2 = function(rrddata, type, opt = {}) {
     else
         record = "kismet.common.rrd.minute_vec";
 
-    var data = [];
-    var rrd_len;
-    var now;
-    var start;
+    let data = [];
+    let rrd_len;
+    let now;
+    let start;
+    let fill_val = 0;
 
-    try {
-        data = rrddata[record];
-
-        if (typeof(data) === 'number')
-            throw(0);
-
-        now = rrddata['kismet.common.rrd.serial_time'];
-        start = rrddata['kismet.common.rrd.last_time'];
-    } catch (e) {
+    if (rrddata == undefined || rrddata[record] == undefined) {
         now = 0;
         start = 0;
 
         if (type == exports.RRD_SECOND || type == exports.RRD_MINUTE) {
             data = [
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
             ];
         } else if (type == exports.RRD_HOUR) {
             data = [
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                 0, 0, 0, 0
             ];
         }
+    } else {
+        data = rrddata[record];
+
+        if (typeof(data) === 'number')
+            throw(0);
+
+        // fill_val = rrddata['kismet.common.rrd.blank_val'];
+
+        now = rrddata['kismet.common.rrd.serial_time'];
+        start = rrddata['kismet.common.rrd.last_time'];
     }
 
     rrd_len = data.length;
@@ -242,43 +245,38 @@ exports.RecalcRrdData2 = function(rrddata, type, opt = {}) {
     // be filled with only zeroes
     //
     // To zero the array between "then" and "now", we simply calculate
-    // the bin for "then", the bin for "now", and increment-with-modulo 
+    // the bin for "then", the bin for "now", and increment-with-modulo
     // until we reach "now".
 
     // Adjusted data we return
-    var adj_data = new Array();
+    let adj_data = new Array();
 
     // Check if we're past the recording bounds of the rrd for this type, if we
     // are, we don't have to do any shifting or any manipulation, we just fill
     // the array with zeroes.
     if ((now - start) > (type * rrd_len)) {
-        for (var ri = 0; ri < rrd_len; ri++) {
+        for (let ri = 0; ri < rrd_len; ri++) {
             adj_data.push(0);
         }
     } else {
         // Otherwise, we're valid inside the range of the array.  We know we got
-        // no data between the time of the RRD and now, because if we had, the 
+        // no data between the time of the RRD and now, because if we had, the
         // time would be more current.  Figure out how many bins lie between
         // 'then' and 'now', rescale the array to start at 'now', and fill
         // in the time we got no data with zeroes
-        
-        var start_bin = (Math.floor(start / type) % rrd_len) + 1;
-        var now_bin = (Math.floor(now / type) % rrd_len) + 1;
-        var sec_offt = Math.max(0, now - start);
 
-        /*
-        console.log("we think we start in bin" + start_bin);
-        console.log("we think now is bin" + now_bin);
-        */
+        let start_bin = (Math.floor(start / type) % rrd_len) + 1;
+        let now_bin = (Math.floor(now / type) % rrd_len) + 1;
+        let sec_offt = Math.max(0, now - start);
 
         // Walk the entire array, starting with 'now', and copy zeroes
         // when we fall into the blank spot between 'start' and 'now' when we
         // know we received no data
-        for (var ri = 0; ri < rrd_len; ri++) {
-            var slot = (now_bin + ri) % rrd_len;
+        for (let ri = 0; ri < rrd_len; ri++) {
+            let slot = (now_bin + ri) % rrd_len;
 
             if (slot >= start_bin && slot < now_bin)
-                adj_data.push(0);
+                adj_data.push(fill_val);
             else
                 adj_data.push(data[slot]);
         }
@@ -287,7 +285,7 @@ exports.RecalcRrdData2 = function(rrddata, type, opt = {}) {
     // If we have a transform function in the options, call it, otherwise
     // return the shifted RRD entry
     if ('transform' in opt && typeof(opt.transform) === 'function') {
-        var cbopt = {};
+        let cbopt = {};
 
         if ('transformopt' in opt)
             cbopt = opt.transformopt;
@@ -298,41 +296,60 @@ exports.RecalcRrdData2 = function(rrddata, type, opt = {}) {
     return adj_data;
 }
 
-// 'drag' the last value of the RRD forwards over zeroes
+// 'drag' the last value of the RRD forwards over zeroes.
+// This manipulates the data to "look" better in a display, at the cost of veracity of the contents,
+// but for visualization this is where we want to be
 exports.RrdDrag = function(data, opt, rrd) {
-    var ret = new Array();
 
-    var last = 0;
-    var last_pos = -1;
+    // Find empty elements in the array
+    // If there are no elements before the empty slot, fill with the next non-zero element
+    // If there are elements before and after the empty slot, fill with the average of the bounding elements
+    // If there are no elements after the empty slot, fill with the last valid value
 
-    for (var ri = 0; ri < data.length; ri++) {
-        if (data[ri] != rrd['kismet.common.rrd.blank_val']) {
-            last = data[ri];
-            last_pos = ri;
-            break;
+    const nilval = rrd['kismet.common.rrd.blank_val'] ;
+    let last = [nilval, -1];
+
+    // find the next fill forward from where we are
+    let find_fill_forward = (pos) => {
+        for (let ri = pos; ri < data.length; ri++) {
+            if (data[ri] !== nilval) {
+                return [data[ri], ri];
+            }
         }
 
-        ret.push(0);
-    }
+        return [nilval, data.length];
+    };
 
-    if (last_pos == -1)
-        return ret;
+    // fill nil values with their future value
+    let fill = [nilval, -1];
 
-    if ('backfill' in opt && opt['backfill'] == true) {
-        ret = new Array();
-        last_pos = 0;
-    }
-
-    for (var ri = last_pos; ri < data.length; ri++) {
-        if (data[ri] == rrd['kismet.common.rrd.blank_val']) {
-            ret.push(last);
+    for (let ri = 0; ri < data.length; ri++) {
+        if (data[ri] !== nilval) {
+            last = [data[ri], ri];
             continue;
         }
 
-        ret.push(data[ri]);
-    }
+        if (data[ri] === nilval) {
+            // if we don't know the next filled value, find it
+            if (fill[0] === nilval || fill[1] < ri) {
+                fill = find_fill_forward(ri + 1);
+            }
 
-    return ret;
+            if (last[0] != nilval) {
+                // no future fill value, known last value
+                if (fill[0] == nilval) {
+                    data[ri] = last[0];
+                    continue;
+                }
+
+                // weighted average
+                data[ri] = ((last[0] * (ri - last[ri])) + (fill[0] * (fill[1] - ri))) / (fill[1] - last[1]);
+            } else if (fill[0] != nilval) {
+                data[ri] = fill[0];
+            }
+        }
+    }
+    return data;
 }
 
 
@@ -415,7 +432,7 @@ exports.censorMAC = function(t) {
 /* Censor a location by rounding */
 exports.censorLocation = function(t) {
     try {
-        if (window['censor_location']) 
+        if (window['censor_location'])
             return `${Math.round(t)}.XXXXX`;
         else
             return t;
@@ -425,18 +442,18 @@ exports.censorLocation = function(t) {
 }
 
 /* Censor a string by obscuring most of the contents */
-exports.censorString = function(t) { 
-    try { 
-        if (window['censor_macs']) { 
-            if (t.length < 6) { 
+exports.censorString = function(t) {
+    try {
+        if (window['censor_macs']) {
+            if (t.length < 6) {
                 return new Array(t.length + 1).join('X');
-            } else { 
+            } else {
                 return t.substring(0, 2) + (new Array(t.length - 3).join('X')) + t.substring(t.length - 2, t.length);
             }
-        } else { 
+        } else {
             return t;
         }
-    } catch (e) { 
+    } catch (e) {
         return t;
     }
 }
@@ -474,16 +491,16 @@ String.prototype.convertNewlines = function() {
     return s;
 }
 
-String.prototype.MiddleShorten = function(len) { 
+String.prototype.MiddleShorten = function(len) {
     if (this.length > len) {
         let epos = len / 2;
         let lpos = this.length - (len / 2);
 
-        while (epos > 1 && this.substr(epos - 1, 1) == ' ') { 
+        while (epos > 1 && this.substr(epos - 1, 1) == ' ') {
             epos = epos - 1;
         }
 
-        while (lpos < len && this.substr(lpos, 1) == ' ') { 
+        while (lpos < len && this.substr(lpos, 1) == ' ') {
             lpos = lpos + 1;
         }
 
@@ -493,19 +510,19 @@ String.prototype.MiddleShorten = function(len) {
     return this;
 }
 
-exports.ExtractDeviceName = function(device) { 
+exports.ExtractDeviceName = function(device) {
     var ret = device['kismet.device.base.username'];
-    if (ret != null && ret != '') { 
+    if (ret != null && ret != '') {
         return exports.censorString(ret);
     }
 
     ret = device['kismet.device.base.name'];
-    if (ret != null && ret != '') { 
+    if (ret != null && ret != '') {
         return exports.censorString(ret);
     }
 
     ret = device['kismet.device.base.commonname'];
-    if (ret != null && ret != '') { 
+    if (ret != null && ret != '') {
         return exports.censorString(ret);
     }
 
